import { BasicColumn, FormSchema } from '/@/components/Table'
import { rules } from '/@/utils/helper/validator'
//列表数据
export const columns: BasicColumn[] = [
  {
    title: '药材编号',
    align: 'center',
    dataIndex: 'code',
  },
  {
    title: '药材名称',
    align: 'center',
    dataIndex: 'name',
  },
  {
    title: '药材分类',
    align: 'center',
    dataIndex: 'type_dictText',
  },
  {
    title: '药材别名',
    align: 'center',
    dataIndex: 'alias',
  },
  {
    title: '药用部位',
    align: 'center',
    dataIndex: 'parts',
  },

  {
    title: '初始含水率',
    align: 'center',
    dataIndex: 'initial',
  },
  {
    title: '目标含水率',
    align: 'center',
    dataIndex: 'target',
  },
  {
    title: '投料量（筐）',
    align: 'center',
    dataIndex: 'feed',
  },
  {
    title: '预计干燥时间',
    align: 'center',
    dataIndex: 'et',
  },
  {
    title: '热风温度',
    align: 'center',
    dataIndex: 'windTemp',
  },
  {
    title: '环境温度',
    align: 'center',
    dataIndex: 'envTemp',
  },
  {
    title: '环境湿度',
    align: 'center',
    dataIndex: 'envHum',
  },
  {
    title: '荡料延时（ms）',
    align: 'center',
    dataIndex: 'delay',
  },
  {
    title: '翻料次数',
    align: 'center',
    dataIndex: 'turn',
  },
  {
    title: '干燥方法',
    align: 'center',
    dataIndex: 'dryMethod',
  },

  {
    title: '注意事项',
    align: 'center',
    dataIndex: 'notice',
  },
  {
    title: '特性标签',
    align: 'center',
    dataIndex: 'tag',
  },
]
//查询数据
export const searchFormSchema: FormSchema[] = [
  {
    label: '药材编号',
    field: 'code',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '药材名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '药材分类',
    field: 'type',
    component: 'JTreeSelect',
    componentProps: {
      dict: 'dry_herb_type,name,id',
      pidField: 'pid',
      hasChildField: 'has_child',
      converIsLeafVal: 1,
    },
    colProps: { span: 6 },
  },
]
//表单数据
export const formSchema: FormSchema[] = [
  {
    label: '药材编号',
    field: 'code',
    component: 'Input',
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请输入药材编号!' }, { ...rules.duplicateCheckRule('dry_herb', 'code', model, schema)[0] }]
    },
  },
  {
    label: '药材名称',
    field: 'name',
    component: 'Input',
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请输入药材名称!' }, { ...rules.duplicateCheckRule('dry_herb', 'name', model, schema)[0] }]
    },
  },
  {
    label: '药材分类',
    field: 'type',
    component: 'JTreeSelect',
    componentProps: {
      dict: 'dry_herb_type,name,id',
      pidField: 'pid',
      hasChildField: 'has_child',
      converIsLeafVal: 1,
    },
    dynamicRules: ({ model, schema }) => {
      return [{ required: true, message: '请输入药材分类!' }]
    },
  },
  {
    label: '药材别名',
    field: 'alias',
    component: 'Input',
  },
  {
    label: '药用部位',
    field: 'parts',
    component: 'Input',
  },

  {
    label: '初始含水率',
    field: 'initial',
    component: 'InputNumber',
  },
  {
    label: '目标含水率',
    field: 'target',
    component: 'InputNumber',
  },
  {
    label: '投料量',
    field: 'feed',
    component: 'InputNumber',
  },
  {
    label: '预计干燥时间',
    field: 'et',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '热风温度',
    field: 'windTemp',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '环境温度',
    field: 'envTemp',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '环境湿度',
    field: 'envHum',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '荡料延时',
    field: 'delay',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '翻料次数',
    field: 'turn',
    component: 'InputNumber',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
    },
  },
  {
    label: '干燥方法',
    field: 'dryMethod',
    component: 'Input',
  },

  {
    label: '注意事项',
    field: 'notice',
    component: 'Input',
  },
  {
    label: '特性标签',
    field: 'tag',
    component: 'Input',
  },
  // TODO 主键隐藏字段，目前写死为ID
  {
    label: '',
    field: 'id',
    component: 'Input',
    show: false,
  },
]

/**
 * 流程表单调用这个方法获取formSchema
 * @param param
 */
export function getBpmFormSchema(_formData): FormSchema[] {
  // 默认和原始表单保持一致 如果流程中配置了权限数据，这里需要单独处理formSchema
  return formSchema
}
